/* eslint-disable @next/next/no-img-element */

import { CslpTag } from '@nuskin/foundation-ui-components';

import { parseJsonString } from '../utils';
import { BynderImageDataType, getImageType, getMediaUrl, getUrlBasedOnDerivative } from '../utils/bynder-util';

type BynderImageProps = {
    imageText: string;
    suffix?: string;
    className?: string;
    testId?: string;
    liveTag?: CslpTag;
};
export const BynderImage = ({ imageText = '', suffix, className, testId, liveTag }: BynderImageProps) => {
    const imageJson = parseJsonString(imageText);
    const image: BynderImageDataType = imageJson?.image?.[0] || {};
    const { files, name, selected, previewUrls, isPublic } = image;
    const { url = '', fit, position, altText = '', bgColor, type } = selected ?? {};
    const imageDerivativeType = getImageType(url, name, files);
    const mediaUrl = getMediaUrl(selected, isPublic, previewUrls);
    let transformedMediaUrl = getUrlBasedOnDerivative(mediaUrl, imageDerivativeType, suffix ?? '');
    if (type === 'VIDEO') {
        return (
            <video
                loop
                autoPlay
                muted
                width="100%"
                {...liveTag}
                style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
                className={`${className || ''} bynder-image`}
                data-testid={testId || 'test-bynder-video'}
            >
                <source src={transformedMediaUrl} type="video/mp4" />
                <source src={transformedMediaUrl} type="video/ogg" />
            </video>
        );
    }
    return (
        <img
            {...liveTag}
            data-testid={testId || 'test-bynder-image'}
            className={`${className || ''} bynder-image`}
            src={transformedMediaUrl}
            alt={altText}
            style={{ backgroundColor: bgColor, objectFit: fit, objectPosition: position }}
        />
    );
};
