import { addEditableTags } from '@contentstack/utils';
import { useEffect, useState } from 'react';

import { referenceMap } from '../nuskin-content-stack';
import {
    ContentStackEnv,
    getContentTypeData,
    getPageContent,
    isInsideIframe,
    languageMap,
    ns_default_header,
    ns_default_utilitybar,
    ns_ffg_footer,
    onEntryChange,
    processReferences
} from '../utils';

const useLivePreviewHook = (props: any) => {
    const { fetchProps } = props;
    const [stateProps, setStateProps] = useState(props);
    const fetchDetails = async () => {
        const pageContent = getPageContent(
            fetchProps?.pageName,
            fetchProps?.languageCode,
            fetchProps?.slug,
            fetchProps?.domain
        );
        const headerData = getContentTypeData(ns_default_header, referenceMap.ns_default_header);
        const footerData = getContentTypeData(ns_ffg_footer);
        const utilityBarData = getContentTypeData(ns_default_utilitybar);

        const [pageResponse, headerRes, footerRes, utilityRes] = await Promise.allSettled([
            pageContent,
            headerData,
            footerData,
            utilityBarData
        ]);
        if (pageResponse) {
            const language = languageMap?.[fetchProps?.languageCode] || fetchProps?.languageCode;
            const pageRes = processReferences(pageResponse, headerRes, footerRes, utilityRes);
            addEditableTags({ ...(pageRes?.value || {}) }, fetchProps?.pageName, true, language);
            setStateProps({ ...pageRes?.value, headerRes: props?.headerRes });
        }
    };

    useEffect(() => {
        if (
            ContentStackEnv.CONTENT_STACK_LIVE_PREVIEW === 'true' &&
            fetchProps &&
            isInsideIframe()
        ) {
            onEntryChange(fetchDetails);
        }
    }, []);

    return stateProps;
};
export default useLivePreviewHook;
