import { useRouter } from 'next/router';

import FoundationPages from '../config/routeConfig';
import type { FoundationPageType  } from '../config/routeConfig';

import EquinoxPages from '../config/equinoxRouteConfig';
import type { EquinoxPageType  } from '../config/equinoxRouteConfig';

import { getRegionAndLanguageFromQuery, isBrowser } from '../utils';


export type PageRoutesType = EquinoxPageType | FoundationPageType;

const usePageRoutes = () => {
    const router = useRouter();
    const { region, language } = getRegionAndLanguageFromQuery(router.query) || {};
    
    const getUrl = (page: PageRoutesType, path?: string, options?: { withOrigin: boolean }) => {
        let url = '';
        let attachOrigin = options?.withOrigin || false;
        if (page in FoundationPages) {
            const pageName = FoundationPages[page as FoundationPageType];
            const pathName = path ? `/${path}` : '';
            const pageWithPath = pageName ? `${pageName}${pathName}` : path;
            url += `/${region}/${language}/site/${pageWithPath}`;
        } else if (page in EquinoxPages){
            const pageName = EquinoxPages[page as EquinoxPageType];
            const pathName = path ? `/${path}` : '';
            const pageWithPath = pageName ? `${pageName}${pathName}` : path;
            attachOrigin = true;
            url += `${region}/${language}/${pageWithPath}`;
        } else if (path && !/^https?:\/\//.test(path)) {
            attachOrigin = true;
            url = path;
        } else if (path) {
            url = path;
        }
        if (isBrowser() && attachOrigin) {
            const origin = window?.location?.origin || '';
            url = `${origin}/${url}`;
        }
        return url;
    };

    const navigate = (page: PageRoutesType, path?: string) => {
        if (page in FoundationPages) {
            const url = getUrl(page, path);
            if (url) {
                router.push(url);
            }
        } else if (page in EquinoxPages){
            const url = getUrl(page, path);
            if (url) {
                window?.location?.replace(url);
            }
        } else {
            window?.location?.replace(page);
        }
    };

    return {
        navigate,
        getUrl
    };

};

export default usePageRoutes;

