import { getCookie } from 'cookies-next';

import { getEnvironmentValues } from './env-utils';

import { generateStoreFrontUrl, getStoreId } from './store-front';

import { sessionCookieId } from '../config/appConfig';

export const getSignInUrl = () => {
    const env = getEnvironmentValues();

    const scope = 'user_profile+openid+profile+email';
    const responseType = 'code';

    const state = env.OKTA_SECRET;
    const clientId = env.OKTA_CLIENT_ID;
    const signInBaseUrl = env.SIGN_IN_URL;

    const urlParams = new URLSearchParams({
        response_type: responseType,
        state,
        client_id: clientId,
        redirect_uri: env.SIGN_IN_REDIRECT
    });

    const urlSearchParamString = urlParams?.toString() || '';

    return `${signInBaseUrl}?scope=${scope}&${urlSearchParamString}`;
};


export const getStoreFrontSignInUrl = async (locale: string) => {
    const storeId = getStoreId();
    const storeFrontSignInUrl = generateStoreFrontUrl('customers/nextgen/okta/authorize', {
        storeId,
        locale: String(locale),
        'App-Name': 'cft'
    });
    return storeFrontSignInUrl;
};

export const getSessionCookie = () => {
    const location = window?.location;
    const host = location?.hostname;
    if (host) {
        return getCookie(sessionCookieId, {
            domain: `.${host}`
        });
    }
};